@@ -214,6 +214,8 @@ def run(properties, explore, cpus=None):
             mission = None
             mode = get_from_user_or_config_or_default(target_configs, sherlock_user_properties, "MODE", "GLOBAL")
             sectors = get_from_user_or_config_or_default(target_configs, sherlock_user_properties, "SECTORS", "all")
+            use_harmonics_spectra = get_from_user_or_config_or_default(target_configs, sherlock_user_properties, "USE_HARMONICS_SPECTRA", False)
+            truncate_border = get_from_user_or_config_or_default(target_configs, sherlock_user_properties, "TRUNCATE_BORDERS_DAYS", 0)
             if sectors != "all" and len(np.array(sectors).shape) > 1:
                 if mode == "GLOBAL" or mode == "BOTH":
                     for sectors_subset in sectors:
@@ -232,7 +234,7 @@ def run(properties, explore, cpus=None):
                                                                         oscillation_amplitude_threshold,
                                                                         oscillation_ws_scale,
                                                                         oscillation_min_period, oscillation_max_period,
-                                                                        exptime_binning)
+                                                                        exptime_binning, truncate_border)
                         sherlock_target = SherlockTarget(built_object_info,
                                                          detrend_method, detrend_l_min, detrend_l_max, detrends_number,
                                                          detrend_cores,
@@ -249,7 +251,7 @@ def run(properties, explore, cpus=None):
                                                          min_quorum, fit_method, oversampling,
                                                          t0_fit_margin, duration_grid_step, properties, cache_dir,
                                                          ignore_original,
-                                                         pickle_mode)
+                                                         pickle_mode, use_harmonics_spectra)
                         sherlock_targets.append(sherlock_target)
                 if mode == "SECTOR" or mode == "BOTH" and isinstance(built_object_info, MissionObjectInfo):
                     if sectors == 'all':
@@ -269,7 +271,7 @@ def run(properties, explore, cpus=None):
                                                                   reduce_simple_oscillations, oscillation_snr_threshold,
                                                                   oscillation_amplitude_threshold, oscillation_ws_scale,
                                                                   oscillation_min_period, oscillation_max_period,
-                                                                  exptime_binning)
+                                                                  exptime_binning, truncate_border)
                         sherlock_target = SherlockTarget(object_info,
                                                          detrend_method, detrend_l_min, detrend_l_max, detrends_number,
                                                          detrend_cores,
@@ -286,7 +288,7 @@ def run(properties, explore, cpus=None):
                                                          min_quorum, fit_method, oversampling,
                                                          t0_fit_margin, duration_grid_step, properties, cache_dir,
                                                          ignore_original,
-                                                         pickle_mode)
+                                                         pickle_mode, use_harmonics_spectra)
                         sherlock_targets.append(sherlock_target)
             else:
                 built_object_info = lcbuilder.build_object_info(target, author, sectors, file, exptime,
@@ -301,7 +303,7 @@ def run(properties, explore, cpus=None):
                                                                 reduce_simple_oscillations, oscillation_snr_threshold,
                                                                 oscillation_amplitude_threshold, oscillation_ws_scale,
                                                                 oscillation_min_period, oscillation_max_period,
-                                                                exptime_binning)
+                                                                exptime_binning, truncate_border)
                 sherlock_target = SherlockTarget(built_object_info,
                                                  detrend_method, detrend_l_min, detrend_l_max, detrends_number,
                                                  detrend_cores,
@@ -316,7 +318,7 @@ def run(properties, explore, cpus=None):
                                                  period_max, period_protect, best_signal_algorithm, quorum_strength,
                                                  min_quorum, fit_method, oversampling,
                                                  t0_fit_margin, duration_grid_step, properties, cache_dir,
-                                                 ignore_original, pickle_mode)
+                                                 ignore_original, pickle_mode, use_harmonics_spectra)
                 if mode == "GLOBAL" or mode == "BOTH":
                     sherlock_targets.append(sherlock_target)
                 if mode == "SECTOR" or mode == "BOTH" and isinstance(built_object_info, MissionObjectInfo):
@@ -336,7 +338,7 @@ def run(properties, explore, cpus=None):
                                                                   reduce_simple_oscillations, oscillation_snr_threshold,
                                                                   oscillation_amplitude_threshold, oscillation_ws_scale,
                                                                   oscillation_min_period, oscillation_max_period,
-                                                                  exptime_binning)
+                                                                  exptime_binning, truncate_border)
                         sherlock_target = SherlockTarget(object_info,
                                                          detrend_method, detrend_l_min, detrend_l_max, detrends_number,
                                                          detrend_cores,
@@ -353,7 +355,7 @@ def run(properties, explore, cpus=None):
                                                          min_quorum, fit_method, oversampling,
                                                          t0_fit_margin, duration_grid_step, properties, cache_dir,
                                                          ignore_original,
-                                                         pickle_mode)
+                                                         pickle_mode, use_harmonics_spectra)
                         sherlock_targets.append(sherlock_target)
                 if mode != "GLOBAL" and mode != "BOTH" and not (mode == "SECTOR" or mode == "BOTH" and
                                                                 isinstance(built_object_info, MissionObjectInfo)):
