@@ -17,8 +17,6 @@ from sherlockpipe.stability import stability_args_parse, run_stability
 from sherlockpipe.validate import validation_args_parse, run_validate
 from sherlockpipe.vet import run_vet
 
-file_in_working = ''
-
 
 def move_input_to_working(running_file, working_dir):
     filename = os.path.basename(running_file)
@@ -99,7 +97,6 @@ def run_script(input_dir, output_dir, working_dir, cpus, pa):
                                                   'years': years, 'spock': spock,
                                                   'free_params': free_params})
                     run_stability(args)
-                    return ap.parse_args(args)
     finally:
         os.chdir(working_dir)
         if running_file is not None and os.path.exists(running_file):
@@ -115,8 +112,6 @@ def run_script(input_dir, output_dir, working_dir, cpus, pa):
                 send_email(output_file, receiver_address, pa)
             else:
                 logging.warning('Cannot send an email because the receiver email was not provided.')
-        else:
-            logging.info("No pending tasks found")
 
 
 def send_email(filename, receiver_address, pa):
