@@ -23,7 +23,7 @@ from sherlockpipe.ois.OisManager import OisManager
 from lcbuilder.star.HabitabilityCalculator import HabitabilityCalculator
 
 from sherlockpipe.plot.plotting import save_transit_plot
-from sherlockpipe.scoring.helper import compute_border_score
+from sherlockpipe.scoring.helper import compute_border_score, harmonic_spectrum
 from sherlockpipe.transitresult import TransitResult
 from multiprocessing import Pool
 from scipy import stats
@@ -297,7 +297,8 @@ class Sherlock:
                     object_report["transits"] = ""
                 object_report["sectors"] = ','.join(map(str, lc_build.sectors)) \
                     if lc_build.sectors is not None and len(lc_build.sectors) > 0 else None
-                object_report["oi"] = self.__find_matching_oi(sherlock_target.object_info, object_report["period"])
+                object_report["oi"] = self.__find_matching_oi(sherlock_target.object_info, object_report["period"],
+                                                              object_report['t0'])
                 if best_signal_score == 1:
                     logging.info('New best signal is good enough to keep searching. Going to the next run.')
                     time, lcs = self.__apply_mask_from_transit_results(sherlock_target, time, lcs, transit_results,
@@ -505,22 +506,16 @@ class Sherlock:
         logging.info('================================================')
         if sherlock_target.detrend_l_min is not None and sherlock_target.detrend_l_max is not None:
             logging.info("Using user input WL / KS")
-            if sherlock_target.detrend_method == 'gp':
-                self.wl_min[sherlock_id] = sherlock_target.detrend_l_min
-                self.wl_max[sherlock_id] = sherlock_target.detrend_l_max
-            else:
-                self.wl_min[sherlock_id] = sherlock_target.detrend_l_min
-                self.wl_max[sherlock_id] = sherlock_target.detrend_l_max
+            self.wl_min[sherlock_id] = sherlock_target.detrend_l_min
+            self.wl_max[sherlock_id] = sherlock_target.detrend_l_max
         else:
             logging.info("Using transit duration based WL or fixed KS")
-            transit_duration = wotan.t14(R_s=lc_build.star_info.radius, M_s=lc_build.star_info.mass,
-                                         P=sherlock_target.period_protect, small_planet=True)
-            if sherlock_target.detrend_method == 'gp':
-                self.wl_min[sherlock_id] = 3 * transit_duration
-                self.wl_max[sherlock_id] = 20 * transit_duration
-            else:
-                self.wl_min[sherlock_id] = 3 * transit_duration  # minimum transit duration
-                self.wl_max[sherlock_id] = 20 * transit_duration  # maximum transit duration
+            min_transit_duration = wotan.t14(R_s=lc_build.star_info.radius, M_s=lc_build.star_info.mass,
+                                             P=sherlock_target.period_min, small_planet=True)
+            max_transit_duration = wotan.t14(R_s=lc_build.star_info.radius, M_s=lc_build.star_info.mass,
+                                             P=sherlock_target.period_max, small_planet=False)
+            self.wl_min[sherlock_id] = 4 * min_transit_duration
+            self.wl_max[sherlock_id] = 8 * max_transit_duration
         logging.info("wl/ks_min: %.2f", self.wl_min[sherlock_id])
         logging.info("wl/ks_max: %.2f", self.wl_max[sherlock_id])
         logging.info('================================================')
@@ -557,7 +552,7 @@ class Sherlock:
                 str(format(signal_selection.transit_result.border_score, '.2f'))
         file = 'Run_' + str(id_run) + '_SELECTED_' + str(signal_selection.curve_index) + '_' + str(star_info.object_id) + '.png'
         save_transit_plot(star_info.object_id, title, run_dir, file, time, lcs[signal_selection.curve_index],
-                          signal_selection.transit_result, cadence, id_run)
+                          signal_selection.transit_result, cadence, id_run, sherlock_target.use_harmonics_spectra)
         if sherlock_target.pickle_mode == 'all':
             with open(run_dir + 'search_results.pickle', 'wb') as search_results_file:
                 pickle.dump(transit_results, search_results_file, protocol=pickle.HIGHEST_PROTOCOL)
@@ -676,7 +671,7 @@ class Sherlock:
             rp_rs = transit_result.results.rp_rs
             a, habitability_zone = self.habitability_calculator \
                 .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
-            oi = self.__find_matching_oi(object_info, transit_result.period)
+            oi = self.__find_matching_oi(object_info, transit_result.period, transit_result.t0)
             logging.info('%-12s%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
                          "PDCSAP_FLUX", transit_result.period,
                          transit_result.per_err, transit_result.count, transit_result.depth,
@@ -691,7 +686,7 @@ class Sherlock:
                          ' # BS:' + str(format(transit_result.border_score, '.2f'))
             plot_file = 'Run_' + str(id_run) + '_PDCSAP-FLUX_' + str(star_info.object_id) + '.png'
             save_transit_plot(star_info.object_id, plot_title, plot_dir, plot_file, time, lcs[0], transit_result,
-                              cadence, id_run)
+                              cadence, id_run, sherlock_target.use_harmonics_spectra)
         else:
             transit_result = TransitResult(None, None, 0, 0, 0, 0, [], [], 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, [], False)
         transit_results[0] = transit_result
@@ -703,7 +698,7 @@ class Sherlock:
             rp_rs = transit_result.results.rp_rs
             a, habitability_zone = self.habitability_calculator \
                 .calculate_hz_score(star_info.teff, star_info.mass, star_info.lum, transit_result.period)
-            oi = self.__find_matching_oi(object_info, transit_result.period)
+            oi = self.__find_matching_oi(object_info, transit_result.period, transit_result.t0)
             logging.info('%-12.4f%-12.5f%-10.6f%-8s%-18.3f%-14.1f%-14.4f%-12.3f%-12.3f%-16.2f%-14s%-12s%-25.5f%-10.5f%-18.5f%-20s',
                          wl[i], transit_result.period,
                      transit_result.per_err, transit_result.count, transit_result.depth,
@@ -720,14 +715,18 @@ class Sherlock:
                     ' # BS:' + str(format(transit_result.border_score, '.2f'))
             file = 'Run_' + str(id_run) + '_' + detrend_file_name_customs + '=' + str(format(wl[i], '.4f')) + '_' + \
                    str(star_info.object_id) + '.png'
-            save_transit_plot(star_info.object_id, title, plot_dir, file, time, lcs[i], transit_result, cadence, id_run)
+            save_transit_plot(star_info.object_id, title, plot_dir, file, time, lcs[i], transit_result, cadence,
+                              id_run, sherlock_target.use_harmonics_spectra)
         return transit_results
 
-    def __find_matching_oi(self, object_info, period):
+    def __find_matching_oi(self, object_info, period, epoch):
         if self.ois is not None:
+            mission, mission_id, target_id = LcBuilder().parse_object_info(object_info.mission_id())
+            corrected_epoch = LcbuilderHelper.normalize_mission_epoch(mission, epoch)
             existing_period_in_object = self.ois[(self.ois["Object Id"] == object_info.mission_id()) &
-                                                 (0.95 < self.ois["Period (days)"] / period) &
-                                                 (self.ois["Period (days)"] / period < 1.05)]
+                                                 (0.99 < self.ois["Period (days)"] / period) &
+                                                 (self.ois["Period (days)"] / period < 1.01) &
+                                                 (np.abs(self.ois['Epoch (BJD)'] - corrected_epoch) / period < 0.05)]
             existing_period_in_oi = existing_period_in_object[existing_period_in_object["OI"].notnull()]
             oi = existing_period_in_oi["OI"].iloc[0] if len(
                 existing_period_in_oi.index) > 0 else np.nan
@@ -776,10 +775,12 @@ class Sherlock:
         else:
             duration = results['duration']
         harmonic = self.__is_harmonic(results, run_results, report, detrend_source_period)
+        harmonic_power = harmonic_spectrum(results['periods'], results.power)
         return TransitResult(power_args, results, results.period, results.period_uncertainty, duration,
                              results.T0, t0s, depths, depths_err, depth, results.odd_even_mismatch,
                              (1 - results.depth_mean_even[0]) * 1000, (1 - results.depth_mean_odd[0]) * 1000, transit_count,
-                             results.snr, results.SDE, results.FAP, border_score, in_transit, harmonic)
+                             results.snr, results.SDE, results.FAP, border_score, in_transit, harmonic,
+                             harmonic_power)
 
     def __calculate_planet_radius(self, star_info, depth):
         rp = np.nan
