@@ -1,7 +1,7 @@
 class TransitResult:
     def __init__(self, power_args, results, period, per_err, duration,
                  t0, t0s, depths, depths_err, depth, odd_even_mismatch, depth_mean_even, depth_mean_odd, count, snr,
-                 sde, fap, border_score, in_transit, harmonic=None):
+                 sde, fap, border_score, in_transit, harmonic=None, harmonic_spectrum=None):
         self.power_args = power_args
         self.results = results
         self.period = period
@@ -22,3 +22,4 @@ class TransitResult:
         self.border_score = border_score
         self.in_transit = in_transit
         self.harmonic = harmonic
+        self.harmonic_spectrum = harmonic_spectrum
